@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-07-30'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -733,12 +733,13 @@ _
             ($args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
 
             "# PERICMD_INLINE_SCRIPT: ", do {
+                require JSON;
                 my %tmp = %args;
-                # don't show the potentially long argument values
+                # don't show the potentially long/undumpable argument values
                 for (grep {/^code_/} keys %tmp) {
                     $tmp{$_} = "...";
                 }
-                dmp(\%tmp);
+                JSON::encode_json(\%tmp);
             }, "\n\n",
 
             "# This script is generated by ", __PACKAGE__,
@@ -835,7 +836,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.16 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-30.
+This document describes version 0.17 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-30.
 
 =head1 SYNOPSIS
 
@@ -861,23 +862,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           12.905+-0.031/s           --               -61.7%      -82.4%         -88.7%                 -91.5%      -93.8% -97.5%
- run --version (lite)   33.695+-0.078/s 161.1+-0.87%                   --      -53.9%         -70.6%                 -77.7%      -83.9% -93.6%
- -c (lite)                73.15+-0.24/s  466.9+-2.3%        117.11+-0.88%          --         -36.1%                 -51.6%      -65.1% -86.0%
- run 1 (inline)          114.53+-0.71/s  787.4+-5.9%          239.9+-2.2%  56.6+-1.1%             --                 -24.2%      -45.3% -78.2%
- run --version (inline)      151+-1.1/s 1070.2+-9.1%          348.2+-3.5% 106.4+-1.7%     31.9+-1.3%                     --      -27.9% -71.2%
- -c (inline)               209.3+-1.4/s    1522+-12%          521.3+-4.5% 186.1+-2.2%     82.8+-1.7%             38.6+-1.4%          -- -60.1%
- perl                      524.4+-4.7/s    3964+-38%            1456+-14% 616.8+-6.9%      357.9+-5%              247.3+-4% 150.5+-2.8%     --
+                                   Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) -c (inline) run --version (inline)   perl
+ run 1 (lite)           13.569+-0.013/s            --               -61.0%       -82.0%         -89.1%      -90.6%                 -91.2% -97.1%
+ run --version (lite)   34.785+-0.052/s 156.36+-0.45%                   --       -54.0%         -72.1%      -75.9%                 -77.6% -92.6%
+ -c (lite)                75.56+-0.19/s   456.9+-1.5%        117.23+-0.64%           --         -39.4%      -47.6%                 -51.2% -83.8%
+ run 1 (inline)          124.61+-0.34/s   818.3+-2.6%          258.2+-1.1% 64.91+-0.62%             --      -13.6%                 -19.6% -73.3%
+ -c (inline)               144.3+-3.1/s      963+-23%            314.7+-9%   90.9+-4.2%     15.8+-2.5%          --                  -6.9% -69.1%
+ run --version (inline)    154.9+-1.1/s  1041.9+-8.3%          345.4+-3.3%  105.1+-1.6%   24.35+-0.95%   7.4+-2.5%                     -- -66.9%
+ perl                      467.4+-3.2/s     3345+-24%         1243.8+-9.3%  518.6+-4.5%    275.1+-2.7%   224+-7.4%              201.7+-3%     --
  
  Average times:
-   perl                  :     1.9069ms
-   -c (inline)           :     4.7778ms
-   run --version (inline):     6.6225ms
-   run 1 (inline)        :     8.7313ms
-   -c (lite)             :    13.6705ms
-   run --version (lite)  :    29.6780ms
-   run 1 (lite)          :    77.4893ms
+   perl                  :     2.1395ms
+   run --version (inline):     6.4558ms
+   -c (inline)           :     6.9300ms
+   run 1 (inline)        :     8.0250ms
+   -c (lite)             :    13.2345ms
+   run --version (lite)  :    28.7480ms
+   run 1 (lite)          :    73.6974ms
 
 =head1 FUNCTIONS
 
